==> humhub-1.3.3.tar.gz: humhub-1.3.3/protected/humhub/modules/admin/messages/nb_no/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informasjon</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>innstillinger</strong> og konfigurasjon',
  '<strong>User</strong> administration' => '<strong>Bruker</strong> administrasjon',
  'Active users' => 'Aktive brukere',
  'Add new group' => 'Lag en ny gruppe',
  'Add new user' => 'Legg til en ny bruker',
  'Are you really sure that you want to disable this user?' => 'Er du sikker på at du vil deaktivere denne brukeren?',
  'Are you really sure that you want to enable this user?' => 'Er du sikker på at du vil aktivere denne brukeren?',
  'Are you really sure that you want to impersonate this user?' => 'Er du virkelig sikker på at du vil etterligne denne brukeren?',
  'Are you sure that you want to delete following user?' => 'Er du sikker på at du vil slette denne brukeren?',
  'Cancel' => 'Avbryt',
  'Confirm user deletion' => 'Bekreft sletting av brukeren',
  'Delete all contributions of this user' => 'Slett alle bidrag fra denne brukeren',
  'Delete spaces which are owned by this user' => 'Slett grupper som denne brukeren eier',
  'Deleted users' => 'Slettede brukere',
  'Disable' => 'Deaktiver',
  'Disabled users' => 'Deaktiver bruker',
  'Enable' => 'Aktiver',
  'Group Manager' => 'Gruppe administrasjon',
  'Groups' => 'Grupper',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Hvis dette alternativet ikke er valgt, overføres eierskapet til gruppene til kontoen din.',
  'Impersonate' => 'ligne',
  'Last login' => 'Siste pålogging',
  'List pending registrations' => 'Liste av ventende registreringer',
  'Manage group: {groupName}' => 'Administrer gruppe: {groupName}',
  'Member since' => 'Medlem siden',
  'Members' => 'Medlemmer',
  'Overview' => 'Oversikt',
  'Pending approvals' => 'Ventende godkjenninger',
  'Permanently delete' => 'Permanent slettet',
  'Permissions' => 'Tillatelser',
  'Profiles' => 'Profiler',
  'Search by name, email or id.' => 'Søk etter navn, E-post eller id',
  'Settings' => 'Innstillinger',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Denne oversikten inneholder en liste over hver registrert bruker med handlinger for å vise, redigere og slette brukere.',
  'User deletion process queued.' => 'Bruker sletteprosess i kø.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Ved hjelp av dette alternativet vil eventuelle bidrag (for eksempel innhold, kommentarer eller liker) av denne brukeren bli slettet uoppnåelig.',
  'View profile' => 'Vis profil',
  'You cannot delete yourself!' => 'Du kan ikke slette din egen bruker.',
  'never' => 'Aldri',
);

==> humhub-1.3.10.tar.gz: humhub-1.3.10/protected/humhub/modules/admin/messages/nb_no/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informasjon</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>innstillinger</strong> og konfigurasjon',
  '<strong>User</strong> administration' => '<strong>Bruker</strong> administrasjon',
  'Active users' => 'Aktive brukere',
  'Add new group' => 'Lag en ny gruppe',
  'Add new user' => 'Legg til en ny bruker',
  'Are you really sure that you want to disable this user?' => 'Er du sikker på at du vil deaktivere denne brukeren?',
  'Are you really sure that you want to enable this user?' => 'Er du sikker på at du vil aktivere denne brukeren?',
  'Are you really sure that you want to impersonate this user?' => 'Er du virkelig sikker på at du vil etterligne denne brukeren?',
  'Are you sure that you want to delete following user?' => 'Er du sikker på at du vil slette denne brukeren?',
  'Cancel' => 'Avbryt',
  'Confirm user deletion' => 'Bekreft sletting av brukeren',
  'Delete all contributions of this user' => 'Slett alle bidrag fra denne brukeren',
  'Delete spaces which are owned by this user' => 'Slett grupper som denne brukeren eier',
  'Deleted users' => 'Slettede brukere',
  'Disable' => 'Deaktiver',
  'Disabled users' => 'Deaktiver bruker',
  'Enable' => 'Aktiver',
  'Group Manager' => 'Gruppe administrasjon',
  'Groups' => 'Grupper',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Hvis dette alternativet ikke er valgt, overføres eierskapet til gruppene til kontoen din.',
  'Impersonate' => 'ligne',
  'Last login' => 'Siste pålogging',
  'List pending registrations' => 'Liste av ventende registreringer',
  'Manage group: {groupName}' => 'Administrer gruppe: {groupName}',
  'Member since' => 'Medlem siden',
  'Members' => 'Medlemmer',
  'Overview' => 'Oversikt',
  'Pending approvals' => 'Ventende godkjenninger',
  'Permanently delete' => 'Permanent slettet',
  'Permissions' => 'Tillatelser',
  'Profiles' => 'Profiler',
  'Search by name, email or id.' => 'Søk etter navn, E-post eller id',
  'Settings' => 'Innstillinger',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Denne oversikten inneholder en liste over hver registrert bruker med handlinger for å vise, redigere og slette brukere.',
  'User deletion process queued.' => 'Prosessen med å slette brukeren er lagt i kø.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Ved hjelp av dette alternativet vil eventuelle bidrag (for eksempel innhold, kommentarer eller liker) av denne brukeren bli slettet permanent.',
  'View profile' => 'Vis profil',
  'You cannot delete yourself!' => 'Du kan ikke slette din egen bruker.',
  'never' => 'Aldri',
);
